Clazz.declarePackage("JV");
(function(){
var c$ = Clazz.declareType(JV, "JmolStateCreator", null);
})();
;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
